@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: conduit
 version: 1.2.6.4
-id: conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-key: condu_Cam2rE5K61E3exYRjD0Ajx
+id: conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
+key: condu_I58zpeV6KXSGprp2tu0S0i
 license: MIT
 maintainer: michael@snoyman.com
 homepage: http://github.com/snoyberg/conduit
@@ -25,14 +25,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-1.2.6.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-1.2.6.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-1.2.6.4
-hs-libraries: HSconduit-1.2.6.4-Cam2rE5K61E3exYRjD0Ajx
+hs-libraries: HSconduit-1.2.6.4-I58zpeV6KXSGprp2tu0S0i
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
-    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
+    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
     mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
 haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
